@@ -1,7 +1,7 @@
 def main():
     import sys
-    from . import fuzzallspecs
-    from . import runall
+    from cvdastwrapper import fuzzallspecs
+    from cvdastwrapper import runall
     
     print(sys.argv[1:], "argv")
     if sys.argv[1:]:
