@@ -11,15 +11,15 @@ import sys
 
 import cvdast.CloudvectorDAST
 import shutil
-import runonetest
-import runconfig
-from runconfig import inspecdir
-from runconfig import dlogrespdname
-from runconfig import dloginputdname
-from runconfig import apispeclist, fuzzattacklist
-from html_content_gen import generate_test_report
+from cvdastwrapper import runonetest
+from cvdastwrapper import runconfig
+from cvdastwrapper.runconfig import inspecdir
+from cvdastwrapper.runconfig import dlogrespdname
+from cvdastwrapper.runconfig import dloginputdname
+from cvdastwrapper.runconfig import apispeclist, fuzzattacklist
+from cvdastwrapper.html_content_gen import generate_test_report
 from jinja2 import Environment, FileSystemLoader
-import reportutil
+from cvdastwrapper import reportutil
 
 resultrootn = runconfig.dresultdir + "/" + runconfig.dperadir + "/"
 ainfofname = runconfig.dainfofname
